@@ -23,8 +23,7 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 	errno = 0;
 	if(fchmod(*idst, stat_buf->st_mode) == -1)
 	{
-		print_error("chmod", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+		print_error("chmod", cpinfo->dst, __FILE__, __LINE__, cpdd);
 	}
 
 	/* 管理者権限がある場合のみchownする */
@@ -33,8 +32,7 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 		errno = 0;
 		if(fchown(*idst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 		{
-			print_error("chown", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("chown", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 	}
 
@@ -49,8 +47,7 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 	/* 第四引数は0 or AT_SYMLINK_NOFOLLOW */
 	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
 	{
-		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+		print_error("utimensat", cpinfo->dst, __FILE__, __LINE__, cpdd);
 	}
 }
 
