@@ -26,8 +26,7 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 		errno = 0;
 		if(lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 		{
-			print_error("lchown", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("lchown", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 	}
 
@@ -42,8 +41,7 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 	/* 第四引数は0 or AT_SYMLINK_NOFOLLOW */
 	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
 	{
-		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+		print_error("utimensat", cpinfo->dst, __FILE__, __LINE__, cpdd);
 	}
 }
 
