@@ -3,8 +3,7 @@
 
 #define _GNU_SOURCE
 #define UNLINK_ERR \
-	print_error("unlink", __FILE__, __LINE__, cpdd);\
-	fprintf(stderr, _("error : %s\n"), cpinfo->dst);\
+	print_error("unlink", cpinfo->dst, __FILE__, __LINE__, cpdd);\
 	cpinfo->dst_para = INITIAL;
 
 #include "ch_time_and_mod_link.h"
@@ -61,8 +60,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			if(lstat(cpinfo->src, &stat_src) == -1)
 			{
 				check = false;
-				print_error("lstat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);
+				print_error("lstat", cpinfo->src, __FILE__, __LINE__, cpdd);
 			}
 			else if(lstat(cpinfo->dst, &stat_dst) == -1)
 			{
@@ -73,8 +71,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 				else
 				{
 					check = false;
-					print_error("lstat", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+					print_error("lstat", cpinfo->dst, __FILE__, __LINE__, cpdd);
 				}
 			}
 			else
@@ -121,8 +118,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 
 				default:
 					check = false;
-					print_error("NULL", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, _("option error : %s\n"), cpinfo->src);
+					print_error("NULL", cpinfo->src, __FILE__, __LINE__, cpdd);
 					break;
 				}
 			}
@@ -152,8 +148,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 	if((readlink_len = readlink(cpinfo->src, link_buf, PATH_MAX)) == -1)
 	{
 		check = false;
-		print_error("readlink", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->src);
+		print_error("readlink", cpinfo->src, __FILE__, __LINE__, cpdd);
 	}
 	else
 	{
@@ -174,8 +169,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 		if(symlink(link_buf, cpinfo->dst) == -1)
 		{
 			check = false;
-			print_error("symlink", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("symlink", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 		else
 		{
@@ -196,8 +190,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 
 			if(lstat(cpinfo->src, &stat_buf) == -1)
 			{
-				print_error("lstat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);
+				print_error("lstat", cpinfo->src, __FILE__, __LINE__, cpdd);
 			}
 			else
 			{
