@@ -2,7 +2,7 @@
 
 #include <stdio.h>
 
-static char version[] = "0.16.6 beta";
+static char version[] = "0.16.7 beta";
 
 /* 関数プロトタイプ */
 void help(void);
@@ -14,7 +14,7 @@ void help()
 {
 	printf(_("バージョン : %s\n"), version);
 	puts(_("使用方法   : snowcp [option] src dst"));
-	puts(_("概要       : srcをdstへコピーする。dstが存在しない場合は自動的に作成する。"));
+	puts(_("概要       : 単一または複数の src を dst へコピーする。dstが存在しない場合は自動的に作成する。"));
 	puts("");
 	puts(_("オプション"));
 	puts(_(" -b NUMBER  バッファの量を指定する（MB単位、デフォルト値は32）。"));
