@@ -9,19 +9,24 @@
 
 #include <errno.h>
 
-static void print_error(const char *func, const char *source_file, const int line, CPDD *cpdd);
+static void print_error(const char *func, const char *path, const char *source_code_file_name, const int line, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
-static void print_error(const char *func, const char *source_file, const int line, CPDD *cpdd)
+static void print_error(const char *func, const char *path, const char *source_code_file_name, const int line, CPDD *cpdd)
 {
-	printf(_("%s : %d行\n"), source_file, line);
+	printf(_("%s : %d行\n"), source_code_file_name, line);
 
 	if(strcmp(func, "NULL") != 0)
 	{
 		perror(func);
 	}
 
+	if(strcmp(path, "NULL") != 0)
+	{
+		fprintf(stderr, _("error : %s\n"), path);
+	}
+
 	cpdd->total_error++;
 }
 
