@@ -28,8 +28,7 @@
 	if(idst == -1)\
 	{\
 		is_dio_dst = false;\
-		print_error("open", __FILE__, __LINE__, cpdd);\
-		fprintf(stderr, _("error : %s\n"), cpinfo->dst);\
+		print_error("open", cpinfo->dst, __FILE__, __LINE__, cpdd);\
 	}\
 	else \
 	{\
@@ -214,16 +213,14 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		}
 		else
 		{
-			print_error("open", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->src);
+			print_error("open", cpinfo->src, __FILE__, __LINE__, cpdd);
 		}
 
 		if(b == false)
 		{
 			if((isrc = open(cpinfo->src, O_RDONLY)) == -1)
 			{
-				print_error("open", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);
+				print_error("open", cpinfo->src, __FILE__, __LINE__, cpdd);
 			}
 			else
 			{
@@ -244,8 +241,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		errno = 0;
 		if(fstat(isrc, &stat_buf) == -1)
 		{
-			print_error("fstat", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->src);
+			print_error("fstat", cpinfo->src, __FILE__, __LINE__, cpdd);
 		}
 		else
 		{
@@ -269,8 +265,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			errno = 0;
 			if(stat(cpinfo->dst, &stat_dst) == -1)
 			{
-				print_error("stat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+				print_error("stat", cpinfo->dst, __FILE__, __LINE__, cpdd);
 
 				if(errno == ENOENT)
 				{
@@ -317,8 +312,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		/* Ubuntu 11.04だとfallocateの第二引数は FALLOC_FL_KEEP_SIZE と FALLOC_FL_PUNCH_HOLE の二つ。linux/falloc.h のincludeが必要。 */
 		if(fallocate(idst, FALLOC_FL_KEEP_SIZE, 0, src_size_local) == -1)
 		{
-			print_error("fallocate", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("fallocate", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 /*
 		static int itmp = -1;
@@ -346,8 +340,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		{
 			if(ftruncate(idst, src_size_local) == -1)
 			{
-				print_error("ftruncate", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+				print_error("ftruncate", cpinfo->dst, __FILE__, __LINE__, cpdd);
 			}
 		}
 	}
@@ -357,8 +350,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		if(ftruncate(idst, 0) == -1)
 		{
 			return_dst_ftruncate = -1;
-			print_error("ftruncate", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("ftruncate", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 
 		if(is_verify == true)
@@ -400,15 +392,13 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		{
 			if(posix_fadvise(isrc, 0, 0, POSIX_FADV_DONTNEED) == -1)
 			{
-				print_error("posix_fadvise", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);
+				print_error("posix_fadvise", cpinfo->src, __FILE__, __LINE__, cpdd);
 			}
 		}
 
 		if(close(isrc) == -1)
 		{
-			print_error("close", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->src);
+			print_error("close", cpinfo->src, __FILE__, __LINE__, cpdd);
 		}
 	}
 
@@ -418,15 +408,13 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		{
 			if(posix_fadvise(idst, 0, 0, POSIX_FADV_DONTNEED) == -1)
 			{
-				print_error("posix_fadvise", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+				print_error("posix_fadvise", cpinfo->dst, __FILE__, __LINE__, cpdd);
 			}
 		}
 
 		if(close(idst) == -1)
 		{
-			print_error("close", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("close", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 	}
 
@@ -535,8 +523,7 @@ static inline void rw(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, _Bool is_d
 
 	if((posix_memalign((void **)&buf[0], p_size, buffer_size) != 0) || (posix_memalign((void **)&buf[1], p_size, buffer_size) != 0))
 	{
-		print_error("posix_memalign", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+		print_error("posix_memalign", cpinfo->dst, __FILE__, __LINE__, cpdd);
 	}
 	else
 	{
@@ -562,8 +549,7 @@ static inline void rw(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, _Bool is_d
 		{
 			if(posix_fadvise(isrc, 0, 0, POSIX_FADV_SEQUENTIAL) == -1)
 			{
-				print_error("posix_fadvise", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);
+				print_error("posix_fadvise", cpinfo->src, __FILE__, __LINE__, cpdd);
 			}
 		}
 
@@ -668,8 +654,7 @@ static inline void rw(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, _Bool is_d
 
 				if(r == -1)
 				{
-					print_error("read", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, _("error : %s\n"), cpinfo->src);
+					print_error("read", cpinfo->src, __FILE__, __LINE__, cpdd);
 					break;
 				}
 				else if(r == 0)
@@ -684,8 +669,7 @@ static inline void rw(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, _Bool is_d
 		}
 		else if(r == -1)
 		{
-			print_error("read", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->src);
+			print_error("read", cpinfo->src, __FILE__, __LINE__, cpdd);
 		}
 
 		if(is_verify == true)
@@ -721,15 +705,13 @@ static void * write_normal(void *cpcp_tmp)
 		errno = 0;
 		if((w = write(idst, tmp, endp - tmp)) == -1)
 		{
-			print_error("write", __FILE__, __LINE__, cpcp->cpdd);
-			fprintf(stderr, _("error : %s\n"), cpcp->cpinfo->dst);
+			print_error("write", cpcp->cpinfo->dst, __FILE__, __LINE__, cpcp->cpdd);
 			break;
 		}
 
 		if(sync_file_range(idst, total_write_local, w, SYNC_FILE_RANGE_WAIT_BEFORE | SYNC_FILE_RANGE_WRITE | SYNC_FILE_RANGE_WAIT_AFTER) == -1)
 		{
-			print_error("sync_file_range", __FILE__, __LINE__, cpcp->cpdd);
-			fprintf(stderr, _("error : %s\n"), cpcp->cpinfo->dst);
+			print_error("sync_file_range", cpcp->cpinfo->dst, __FILE__, __LINE__, cpcp->cpdd);
 		}
 
 		tmp += w;
@@ -748,8 +730,7 @@ static void * write_dio(void *cpcp_tmp)
 
 	if((w = write(idst, buf[wi], cpcp->w_size)) == -1)
 	{
-		print_error("write", __FILE__, __LINE__, cpcp->cpdd);
-		fprintf(stderr, _("error : %s\n"), cpcp->cpinfo->dst);
+		print_error("write", cpcp->cpinfo->dst, __FILE__, __LINE__, cpcp->cpdd);
 	}
 	else
 	{
