@@ -15,7 +15,6 @@
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
-#include "print_error.h"
 #include "read_conf.h"
 #include "remove_source_rmdir.h"
 #include "set_signal.h"
@@ -127,9 +126,9 @@ int main(int argc, char **argv)
 
 	if(cpdd->link_count > 0)   { printf(_("Link   : %llu / %llu\n"), cpdd->mk_link_count, cpdd->link_count); }
 	if(cpdd->dir_count > 0)    { printf(_("Dir    : %llu / %llu\n"), cpdd->mk_dir_count, cpdd->dir_count); }
-	if(cpdd->total_source > 0) { printf(_("Source : %llu MB (%llu Bytes)\n"), cpdd->total_source / (1024 * 1024), cpdd->total_source); }
-	if(cpdd->total_read > 0)   { printf(_("Read   : %llu MB (%llu Bytes)\n"), cpdd->total_read / (1024 * 1024), cpdd->total_read); }
-	if(cpdd->total_write > 0)  { printf(_("Write  : %llu MB (%llu Bytes)\n"), cpdd->total_write / (1024 * 1024), cpdd->total_write); }
+	if(cpdd->total_source > 0) { printf(_("Source : %llu MiB (%llu Bytes)\n"), cpdd->total_source / (1024 * 1024), cpdd->total_source); }
+	if(cpdd->total_read > 0)   { printf(_("Read   : %llu MiB (%llu Bytes)\n"), cpdd->total_read / (1024 * 1024), cpdd->total_read); }
+	if(cpdd->total_write > 0)  { printf(_("Write  : %llu MiB (%llu Bytes)\n"), cpdd->total_write / (1024 * 1024), cpdd->total_write); }
 	if(cpdd->total_error > 0)  { printf(_("Error  : %llu\n"), cpdd->total_error); }
 
 	/*
