@@ -94,8 +94,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 
 	if((is_open == true) && (close(fd) == -1))
 	{
-		print_error("close", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+		print_error("close", cpinfo->dst, __FILE__, __LINE__, cpdd);
 	}
 /*
 	free(buf[0]);
@@ -113,8 +112,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 	{
 		if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
 		{
-			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
+			print_error("posix_memalign", cpinfo->dst, __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, "NULL", sdir, cpdd, false);
 			cpinfo->dst_para = INITIAL;
 
@@ -214,8 +212,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 
 		if(is_equal == false)
 		{
-			print_error("NULL", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
+			print_error("NULL", cpinfo->dst, __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, hex_output, sdir, cpdd, false);
 			cpinfo->dst_para = DELETE;
 
@@ -224,8 +221,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			{
 				if(errno != ENOENT)
 				{
-					print_error("unlink", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+					print_error("unlink", cpinfo->dst, __FILE__, __LINE__, cpdd);
 				}
 			}
 			else
