@@ -113,8 +113,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 			}
 			else
 			{
-				print_error("NULL", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
+				print_error("NULL", cpinfo->dst, __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, ddst, sdir, cpdd, false);
 				cpinfo->dst_para = DELETE;
 
@@ -123,8 +122,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 				{
 					if(errno != ENOENT)
 					{
-						print_error("unlink", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+						print_error("unlink", cpinfo->dst, __FILE__, __LINE__, cpdd);
 					}
 				}
 				else
@@ -135,16 +133,14 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 		}
 		else
 		{
-			print_error("NULL", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
+			print_error("NULL", cpinfo->dst, __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
 			cpinfo->dst_para = INITIAL;
 		}
 	}
 	else
 	{
-		print_error("NULL", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
+		print_error("NULL", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
 		cpinfo->dst_para = INITIAL;
 	}
